diff --git a/arch/mips/kernel/vdso.c b/arch/mips/kernel/vdso.c
index f9dbfb1..62952ae 100644
--- a/arch/mips/kernel/vdso.c
+++ b/arch/mips/kernel/vdso.c
@@ -24,6 +24,7 @@
 
 /* Kernel-provided data used by the VDSO. */
 static union mips_vdso_data vdso_data __page_aligned_data;
+static union mips_vdso_data dummy     __page_aligned_data;
 
 /*
  * Mapping for the VDSO data/GIC pages. The real pages are mapped manually, as
@@ -181,6 +182,22 @@ int arch_setup_additional_pages(struct linux_binprm *bprm, int uses_interp)
 	ret = 0;
 
 out:
+	{
+		unsigned long d = data_addr  & 0x00001000LU;
+		unsigned long v = (unsigned long)&vdso_data & 0x00001000LU;
+
+		/*
+		 * Make sure we use #dummy for something or the linker will
+		 * discard it.
+		 */
+
+		/* Bit 12 must be identical in user- and kernel-space */
+		printk(KERN_ERR "tgid = %u, pid = %u, comm = %12s: data_addr = "
+			"0x%08lx, &vdso_data = 0x%p, &dummy = 0x%p => %s\n",
+			current->tgid, current->pid, current->comm, data_addr,
+			&vdso_data, &dummy, d == v ? "aligned" : "NOT ALIGNED");
+        }
+
 	up_write(&mm->mmap_sem);
 	return ret;
 }
